#include "StdAfx.h"
#include "haptics.h"
#include "scene.h"



void initGL() {
	glEnable(GL_DEPTH_TEST);
	
	glCullFace(GL_BACK);
	glEnable(GL_CULL_FACE);
	
	glEnable(GL_LIGHTING);
	glEnable(GL_LIGHT0);
	const GLfloat lightPos[]={-1.0f,1.0f,1.0f,0.0f};
	glLightfv(GL_LIGHT0,GL_POSITION,lightPos);
	
	glEnable(GL_COLOR_MATERIAL);
	
	glClearColor(0.0f,0.0f,0.0f,1.0f);
	glClearDepth(1.0);
}
//--------------------------------------------------------------------------------------------------
void callbackDisplay() {
	// -- Clear --
	glClear(GL_COLOR_BUFFER_BIT | GL_DEPTH_BUFFER_BIT);
	
	// -- Position camera --
	glMatrixMode(GL_MODELVIEW);
	glLoadIdentity();
	#ifdef USE_ROBOTIC_WORLD
		gluLookAt(
			3.0,0.0,0.0
			,0.0,0.0,0.0
			,0.0,0.0,1.0
		);
	#else
		gluLookAt(
			0.0,0.0,3.0
			,0.0,0.0,0.0
			,0.0,1.0,0.0
		);
	#endif
	
	// -- Draw spheres --
	glColor3f(1.0f,1.0f,1.0f);
	glPushMatrix();
	#ifndef USE_ROBOTIC_WORLD
		glRotatef(90.0f,1.0f,0.0f,0.0f);
	#endif
	glutWireSphere(SPHERE_RADIUS,36,18);
	glutSolidSphere(SMALL_SPHERE_RADIUS,360,180);
	glPopMatrix();
	
	// -- Draw proxy --
	updateTool();
	glPushMatrix();
	glTranslated(getToolPosition()[0],getToolPosition()[1],getToolPosition()[2]);
	glColor3f(thickness,1.0f-thickness,0.0f);
	glutSolidSphere(TOOL_RADIUS,36,18);
	glPopMatrix();
	
	// -- Swap buffers --
	glutSwapBuffers();
}
//--------------------------------------------------------------------------------------------------
void callbackReshape(const int newWidth,const int newHeight) {
	GLdouble aspect;
	if (newHeight==0) {
		aspect=GLdouble(newWidth);
	} else {
		aspect=GLdouble(newWidth)/GLdouble(newHeight);
	}
	
	glMatrixMode(GL_PROJECTION);
	glLoadIdentity();
	gluPerspective(60.0,aspect,0.1,10.0);
	
	glViewport(0,0,newWidth,newHeight);
}
//--------------------------------------------------------------------------------------------------
void callbackIdle() {
	//Redraw as often as we're able
	glutPostRedisplay();
}
//--------------------------------------------------------------------------------------------------
void callbackKeyboard(const unsigned char key,const int x,const int y) {
	if (key==27) {
		exit(0);
	}
}
//--------------------------------------------------------------------------------------------------
//--------------------------------------------------------------------------------------------------
void main(int argC,char **argV) {
	glutInit(&argC,argV);
	glutInitDisplayMode(GLUT_RGBA | GLUT_DEPTH | GLUT_DOUBLE);
	glutInitWindowSize(512,512);
	glutCreateWindow("Falcon " HAPTIC_NAME " demo");
	glutDisplayFunc(&callbackDisplay);
	glutReshapeFunc(&callbackReshape);
	glutIdleFunc(&callbackIdle);
	glutKeyboardFunc(&callbackKeyboard);
	initHaptics();
	initGL();
	atexit(&uninitHaptics);
	glutMainLoop();
}
